Coverage report

File | statements | missing | excluded | coverage
--- | --- | --- | --- | ---
src\pncp\__init__.py | 0 | 0 | 0 | 100%
src\pncp\instrumentos_convocatorios\__init__.py | 1 | 0 | 0 | 100%
src\pncp\instrumentos_convocatorios\busca.py | 212 | 0 | 0 | 100%
src\pncp\instrumentos_convocatorios\tipos.py | 253 | 4 | 0 | 98%
src\pncp\tipos.py | 22 | 3 | 0 | 86%
src\pncp\utils.py | 12 | 0 | 0 | 100%
Total | 500 | 7 | 0 | 99%

No items found using the specified filter.